summaryrefslogtreecommitdiffstats
path: root/kchart/kchartParameter3dConfigPage.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kchart/kchartParameter3dConfigPage.cc')
-rw-r--r--kchart/kchartParameter3dConfigPage.cc24
1 files changed, 12 insertions, 12 deletions
diff --git a/kchart/kchartParameter3dConfigPage.cc b/kchart/kchartParameter3dConfigPage.cc
index 39005e29..760c9786 100644
--- a/kchart/kchartParameter3dConfigPage.cc
+++ b/kchart/kchartParameter3dConfigPage.cc
@@ -23,7 +23,7 @@
#include <kapplication.h>
#include <kdialog.h>
#include <klocale.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqcheckbox.h>
#include <tqbuttongroup.h>
@@ -38,17 +38,17 @@ KChartParameter3dConfigPage::KChartParameter3dConfigPage( KChartParams* params,
TQWidget* parent ) :
TQWidget( parent ),m_params( params )
{
- TQGridLayout* layout = new TQGridLayout(this, 2, 2,KDialog::marginHint(),KDialog::spacingHint());
+ TQGridLayout* tqlayout = new TQGridLayout(this, 2, 2,KDialog::marginHint(),KDialog::spacingHint());
TQButtonGroup* gb = new TQButtonGroup( 0, Qt::Vertical,
i18n("3D Parameters"), this );
- gb->layout()->setSpacing(KDialog::spacingHint());
- gb->layout()->setMargin(KDialog::marginHint());
+ gb->tqlayout()->setSpacing(KDialog::spacingHint());
+ gb->tqlayout()->setMargin(KDialog::marginHint());
- // The grid layout inside the buttongroup.
- TQGridLayout *grid1 = new TQGridLayout(gb->layout(), 5, 3);
- layout->addWidget(gb,0,0);
+ // The grid tqlayout inside the buttongroup.
+ TQGridLayout *grid1 = new TQGridLayout(gb->tqlayout(), 5, 3);
+ tqlayout->addWidget(gb,0,0);
// The main on/off checkbox.
bar3d=new TQCheckBox(i18n("3D bar"),gb);
@@ -64,7 +64,7 @@ KChartParameter3dConfigPage::KChartParameter3dConfigPage( KChartParams* params,
grid1->addWidget(drawShadowColor,1,0);
TQLabel *tmpLabel = new TQLabel( i18n( "Angle:" ), gb );
- tmpLabel->resize( tmpLabel->sizeHint() );
+ tmpLabel->resize( tmpLabel->tqsizeHint() );
grid1->addWidget(tmpLabel,2,0);
angle3d=new KIntNumInput(0, gb, 10);
@@ -73,16 +73,16 @@ KChartParameter3dConfigPage::KChartParameter3dConfigPage( KChartParams* params,
angle3d->setRange(0, 90, 1);
tmpLabel = new TQLabel( i18n( "Depth:" ), gb );
- tmpLabel->resize( tmpLabel->sizeHint() );
+ tmpLabel->resize( tmpLabel->tqsizeHint() );
grid1->addWidget(tmpLabel,3,0);
depth=new KDoubleNumInput(0, gb);
TQWhatsThis::add(depth, i18n("You can set here the depth of the 3D effect from 0 to 2. 0 will give you no depth at all.\nDefault is 1."));
- depth->resize(100,depth->sizeHint().height());
+ depth->resize(100,depth->tqsizeHint().height());
grid1->addWidget(depth,3,1);
depth->setRange(0, 2.0, 0.1);
- gb->setAlignment(TQt::AlignLeft);
+ gb->tqsetAlignment(TQt::AlignLeft);
grid1->addColSpacing(0,depth->width());
grid1->addColSpacing(0,angle3d->width());
grid1->setColStretch(2,1);
@@ -90,7 +90,7 @@ KChartParameter3dConfigPage::KChartParameter3dConfigPage( KChartParams* params,
//it's not good but I don't know how
//to reduce space
- //layout->addColSpacing(1,300);
+ //tqlayout->addColSpacing(1,300);
}